// src/index.ts
import { createAssert, createValidate, createWrap } from "@typeschema/core";

// src/validation.ts
var validationAdapter = async (schema) => {
  return async (data) => {
    try {
      return {
        data: await schema(data),
        success: true
      };
    } catch (error) {
      if (error instanceof Error) {
        return {
          issues: [{ message: error.message }],
          success: false
        };
      }
      throw error;
    }
  };
};

// src/index.ts
var validate = createValidate(validationAdapter);
var assert = createAssert(validate);
var wrap = createWrap(assert, validate);
export {
  assert,
  validate,
  validationAdapter,
  wrap
};
